@@ -120,7 +120,7 @@ typedef enum parser_sample_vendor_t {
 	SAMPLE_VENDOR_UWATEC_SMART,
 	SAMPLE_VENDOR_OCEANIC_VTPRO,
 	SAMPLE_VENDOR_OCEANIC_VEO250,
-	SAMPLE_VENDOR_OCEANIC_ATOM2
+	SAMPLE_VENDOR_OCEANIC_ATOM2,
 } parser_sample_vendor_t;
 
 typedef enum dc_water_t {
